Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(375)

Unified Diff: media/base/yuv_convert.cc

Issue 1030253002: Fix missing symbols for pre-linking of the Cast sender library for iOS. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Update media/base/BUILD.gn. Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/base/BUILD.gn ('k') | media/media.gyp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/yuv_convert.cc
diff --git a/media/base/yuv_convert.cc b/media/base/yuv_convert.cc
index d4c1d900b2cc5decb8095fcb46566d7662a92fad..9bc9a93197c042112c587ced34806a9601346647 100644
--- a/media/base/yuv_convert.cc
+++ b/media/base/yuv_convert.cc
@@ -244,8 +244,9 @@ void InitializeCPUSpecificYUVConversions() {
g_convert_yuva_to_argb_proc_ = ConvertYUVAToARGB_C;
g_empty_register_state_proc_ = EmptyRegisterStateStub;
- // Assembly code confuses MemorySanitizer.
-#if defined(ARCH_CPU_X86_FAMILY) && !defined(MEMORY_SANITIZER)
+ // Assembly code confuses MemorySanitizer. Also not available in iOS builds.
+#if defined(ARCH_CPU_X86_FAMILY) && !defined(MEMORY_SANITIZER) && \
+ !defined(OS_IOS)
g_convert_yuva_to_argb_proc_ = ConvertYUVAToARGB_MMX;
#if defined(MEDIA_MMX_INTRINSICS_AVAILABLE)
« no previous file with comments | « media/base/BUILD.gn ('k') | media/media.gyp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698